@@ -5,9 +5,9 @@ package Iterator::Flex::Failure;
 use strict;
 use warnings;
 
-our $VERSION = '0.20';
+our $VERSION = '0.23';
 
-use custom::failures qw/Exhausted Error RoleExists Unsupported/;
+use custom::failures qw/Exhausted Truncated Error RoleExists Unsupported/;
 
 use custom::failures qw/ class parameter internal /;
 
@@ -35,7 +35,7 @@ Iterator::Flex::Failure - Failure classes for Iterator::Flex
 
 =head1 VERSION
 
-version 0.20
+version 0.23
 
 =head1 INTERNALS
 
